AuditEvent class

Constructors

AuditEvent({required String userId, required String name, required String description, required String businessId, required Map<String, String> data, required AuditType type, required AuditSeverity severity, required String deviceId})

Properties

businessId String
final
data Map<String, String>
final
date DateTime
getter/setter pair
description String
final
deviceId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity AuditSeverity
final
type AuditType
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited