AuthSession class

Annotations
  • @JsonSerializable.new()

Constructors

AuthSession({String? userId, String? refreshToken, String? sessionId, String? sessionToken, bool? verified, String? message, String? otpId, List<Business>? businesses})
AuthSession.fromJson(Map<String, dynamic> json)
factory

Properties

businesses List<Business>?
getter/setter pair
businessUsers List<BusinessUser>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
otpId String?
getter/setter pair
refreshToken String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
getter/setter pair
sessionToken String?
getter/setter pair
userId String?
getter/setter pair
verified bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited