AuthSessionUserInfo class

Represents a simplified view of user information.

Annotations
  • @JsonSerializable.new()

Constructors

AuthSessionUserInfo({required String username, required String email, required String firstName, required String lastName, required String? prefix, required String? countryCode, required String? profileImageUri, required String userId})
const
AuthSessionUserInfo.fromJson(Map<String, dynamic> json)
factory

Properties

countryCode String?
The country code associated with the user.
final
email String
The user's email address.
final
firstName String
The user's first name.
final
hashCode int
The hash code for this object.
no setterinherited
lastName String
The user's last name.
final
prefix String?
The user's name prefix (e.g., Mr., Ms.).
final
profileImageUri String?
The URI for the user's profile image.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
The unique identifier for the user.
final
username String
The username.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited