AuthUserRole class

Annotations
  • @JsonSerializable.new()

Constructors

AuthUserRole({required String id, required String name, required String description, required List<String> permissions, required String? businessId, required bool systemRole, required bool enabled, required String userId})
AuthUserRole.fromJson(Map<String, dynamic> json)
factory

Properties

businessId String?
getter/setter pair
description String
getter/setter pair
enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
name String
getter/setter pair
permissions List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemRole bool
getter/setter pair
userId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

mapFromDto({required AuthUserRoleDto userRole, required AuthBusinessRoleDto businessRole}) AuthUserRole