AuthUserRoleDto class

Annotations
  • @JsonSerializable.new()

Constructors

AuthUserRoleDto({required String id, required String businessId, required String roleId, required String userId, required bool deleted, required DateTime? dateCreated, required DateTime? dateUpdated, String? createdBy, String? updatedBy})
AuthUserRoleDto.fromJson(Map<String, dynamic> json)
factory

Properties

businessId String
getter/setter pair
createdBy String?
getter/setter pair
dateCreated DateTime?
getter/setter pair
dateUpdated DateTime?
getter/setter pair
deleted bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
getter/setter pair
roleId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedBy String?
getter/setter pair
userId String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited