AuthenticationResult typedef
AuthenticationResult = AuthResult
Alias so consumers referencing the old class name still compile
Implementation
typedef AuthenticationResult = AuthResult;
Alias so consumers referencing the old class name still compile
typedef AuthenticationResult = AuthResult;