UserPermissions class
- Annotations
-
- @JsonSerializable.new()
Constructors
- UserPermissions({bool? isAdmin = false, bool? manageBusiness = false, bool? manageCustomers = true, bool? manageEmployees = false, bool? manageProducts = true, bool? managePromotions = false, bool? manageInventory = true, bool? manageSuppliers = true, bool? manageUsers = false, bool? analytics = false, bool? giveDiscounts = true, bool makeSale = true, bool? manageExpenses = true, bool isOwner = false, bool? manageOnline = true, bool? manageTransactions = true})
-
UserPermissions.fromJson(Map<
String, dynamic> json) -
factory
Properties
- analytics ↔ bool?
-
getter/setter pair
- giveDiscounts ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAdmin ↔ bool?
-
getter/setter pair
- isOwner ↔ bool
-
getter/setter pair
- makeSale ↔ bool
-
getter/setter pair
- manageBusiness ↔ bool?
-
getter/setter pair
- manageCustomers ↔ bool?
-
getter/setter pair
- manageEmployees ↔ bool?
-
getter/setter pair
- manageExpenses ↔ bool?
-
getter/setter pair
- manageInventory ↔ bool?
-
getter/setter pair
- manageOnline ↔ bool?
-
getter/setter pair
- manageProducts ↔ bool?
-
getter/setter pair
- managePromotions ↔ bool?
-
getter/setter pair
- manageSuppliers ↔ bool?
-
getter/setter pair
- manageTransactions ↔ bool?
-
getter/setter pair
- manageUsers ↔ bool?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited