TimeStampedEntity class abstract

Annotations

Constructors

TimeStampedEntity({String? createdBy, String? updatedBy, DateTime? dateCreated, DateTime? dateUpdated, bool? deleted, String? id})

Properties

createdBy String?
getter/setter pair
dateCreated DateTime?
getter/setter pair
dateUpdated DateTime?
getter/setter pair
deleted bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedBy String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited