LittleFishCore class
- Implemented types
Constructors
- LittleFishCore()
-
factory
Properties
- appSettings → AppSettings
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get<
T extends Object> ({String? name, bool autoInitialize = true}) → dynamic -
getAll<
T extends Object> () → List< T> -
getServiceFromList<
T extends Object> ({String? name}) → Future< T?> -
initialize(
dynamic onConfigureDependencies(GetIt injector, String? environment)?, String? environment) → Future< void> -
isRegistered<
T extends Object> ({String? name}) → bool -
logAllRegisteredObjects(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerLazyService<
T extends Object> (T factory(), {String? instanceName, FutureOr dispose(T)?}) → Future< void> -
registerObject<
T extends Object> ({required T instance, String? name}) → Future< void> -
registerService<
T extends Object> ({required T instance, String? name}) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
unregister<
T extends Object> ({String? name}) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → LittleFishCore
-
final