POSPrinter class abstract

Inheritance

Constructors

POSPrinter()

Properties

builder PrinterContentBuilder
no setterinherited
configurationKey String
no setterinherited
core LittleFishCore
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isReady bool
no setterinherited
logger LoggerService
no setterinherited
name String
no setterinherited
printerType PrinterType
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() Future<void>
inherited
cut() Future<void>
inherited
disconnect() Future<void>
inherited
initialise() Future<bool>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCashDrawer() Future<bool>
inherited
print() Future<bool>
inherited
printLegacy(dynamic content) Future<bool>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited