LittleFishPrinter class abstract

Implementers

Constructors

LittleFishPrinter()

Properties

builder PrinterContentBuilder
no setter
configurationKey String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
printerType PrinterType
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect() Future<void>
cut() Future<void>
disconnect() Future<void>
initialise() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCashDrawer() Future<bool>
print() Future<bool>
printLegacy(dynamic content) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited