CameraScanner<T> class abstract

Inheritance

Constructors

CameraScanner()

Properties

core LittleFishCore
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isReady bool
no setterinherited
logger LoggerService
no setterinherited
name String
no setterinherited
provider String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scannerType ScannerType
no setterinherited

Methods

connect() Future<bool>
inherited
disconnect() Future<bool>
inherited
getScanFunctions() Future<List<SupportedScanFunction>>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<bool>
inherited
resume() Future<bool>
inherited
scan({required SupportedScanFunction scanFunction, required ScanMode scanMode, required dynamic onScanResult(T), int scanLimit = 1, Duration scanDelay = const Duration(seconds: 1)}) Future<void>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited