LoggerSettings class

Constructors

LoggerSettings({LogLevel minimumLogLevel = LogLevel.trace, bool enableConsoleOutput = true, bool enableFileOutput = false, LoggerPrinter printer = LoggerPrinter.simple})

Properties

enableConsoleOutput bool
final
enableFileOutput bool
final
hashCode int
The hash code for this object.
no setterinherited
minimumLogLevel LogLevel
final
printer LoggerPrinter
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited