NotificationSettings class

Constructors

NotificationSettings({required bool enabled, Map<String, dynamic> configuration = const {}, bool sound = true, bool vibrate = true})
NotificationSettings.fromJson(Map<String, dynamic> json)
factory

Properties

configuration Map<String, dynamic>
getter/setter pair
enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sound bool
getter/setter pair
vibrate bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited