PaymentService class abstract

Inheritance

Constructors

PaymentService()

Properties

core LittleFishCore
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
logger LoggerService
no setterinherited
orderService OrderService?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminalService TerminalService?
getter/setter pair

Methods

canDoTransaction({required TransactionType transactionType, required String paymentProviderId, String orderId = ''}) Future<bool>
getPaymentProviderDetails({required String providerId}) Future<void>
getPaymentProviders() Future<void>
getPaymentProviderSettings({required String providerId}) Future<void>
getTransactionDetails({required String transactionId}) Future<void>
initialise({required Map<String, dynamic> settings}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processCashback({required String paymentProviderId, String orderId = ''}) Future<bool>
processPurchase({required String paymentProviderId, String orderId = ''}) Future<bool>
processRefund({required String paymentProviderId, String orderId = ''}) Future<bool>
processVoid({required String paymentProviderId, String orderId = ''}) Future<bool>
processWithdrawal({required String paymentProviderId, String orderId = ''}) Future<bool>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited