TerminalService<T> class
abstract
- Inheritance
-
- Object
- LittleFishService
- TerminalService
Constructors
Properties
- canPrint ↔ bool
-
getter/setter pair
- canScanBarcode ↔ bool
-
getter/setter pair
- canTakePayment ↔ bool
-
getter/setter pair
- canTakePhoto ↔ bool
-
getter/setter pair
- core ↔ LittleFishCore
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- kInstance ↔ T?
-
getter/setter pair
- logger → LoggerService
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- terminalType ↔ TerminalType
-
getter/setter pair
Methods
-
getTerminalInfo(
) → Future< TerminalInfo> -
getTerminalValue(
{required String key}) → Future< String> -
initialise(
{required Map< String, dynamic> settings}) → Future<void> -
isTerminalRegistered(
{required TerminalInfo terminalInfo}) → Future< bool> -
isValidTerminal(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerTerminal(
{required TerminalInfo terminalInfo}) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited