ReportClient class abstract

Constructors

ReportClient()

Properties

authService AuthService
no setter
hashCode int
The hash code for this object.
no setterinherited
logger LoggerService
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings ReportSettings
no setter

Methods

getReportById(String businessId, int id) Future<Report>
getReportUrlById(String businessId, int id) Future<String>
getUserReports(String businessId) Future<List<Report>>
initialise(ReportSettings settings) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited