ButtonStyles class

Constructors

ButtonStyles({double elevation = 1.0, double radius = 8.0})
const
ButtonStyles.fromJson(Map<String, dynamic> json)
factory

Properties

elevation double
final
hashCode int
The hash code for this object.
no setterinherited
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? elevation, double? radius}) ButtonStyles
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited