CardStyle class

Constructors

CardStyle({double elevation = 1.0, double radius = 8.0, double margin = 8.0, String clipType = 'none'})
const
CardStyle.fromJson(Map<String, dynamic> json)
factory

Properties

clipType String
final
elevation double
final
hashCode int
The hash code for this object.
no setterinherited
margin double
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? elevation, double? radius, double? margin, String? clipType}) CardStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited