FormStyle class

Constructors

FormStyle({String titleStyle = 'defaultTitle', String subTitleStyle = 'defaultSubTitle', String borderStyle = 'defaultBorder'})
const
FormStyle.fromJson(Map<String, dynamic> json)
factory

Properties

borderStyle String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subTitleStyle String
final
titleStyle String
final

Methods

copyWith({String? titleStyle, String? subTitleStyle, String? borderStyle}) FormStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited