AuthBusinessProfile class
Business profile data returned as part of the user session.
Contains the key fields from the API BusinessProfile that the client needs at login and for business switching, avoiding a separate GET /Business/GetBusinessProfileById call.
- Annotations
-
- @JsonSerializable.new()
Constructors
-
AuthBusinessProfile({String? id, String? parentId, String? name, String? countryCode, String? logoUri, String? masterMerchantId, String? registrationNumber, String? taxNumber, String? mcc, bool? enabled, bool? vatEnabled, String? businessEmail, String? phoneNumber, Map<
String, dynamic> ? type, Map<String, dynamic> ? category, String? description, String? status, List<Map< ? linkedAccounts, String? onlinePaymentsStatus})String, dynamic> > -
AuthBusinessProfile.fromJson(Map<
String, dynamic> json) -
factory
Properties
- businessEmail ↔ String?
-
getter/setter pair
-
category
↔ Map<
String, dynamic> ? -
getter/setter pair
- countryCode ↔ String?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- enabled ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
-
linkedAccounts
↔ List<
Map< ?String, dynamic> > -
getter/setter pair
- logoUri ↔ String?
-
getter/setter pair
- masterMerchantId ↔ String?
-
getter/setter pair
- mcc ↔ String?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- onlinePaymentsStatus ↔ String?
-
getter/setter pair
- parentId ↔ String?
-
getter/setter pair
- phoneNumber ↔ String?
-
getter/setter pair
- registrationNumber ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
getter/setter pair
- taxNumber ↔ String?
-
getter/setter pair
-
type
↔ Map<
String, dynamic> ? -
getter/setter pair
- vatEnabled ↔ bool?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited