PrinterContentBuilder class
Constructors
- PrinterContentBuilder({PrinterFormatter? formatter})
Properties
- formatter ↔ PrinterFormatter
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addBarcode(
String data, {String type = 'CODE128', PrinterTextAlignment alignment = PrinterTextAlignment.center, int width = 2, int height = 64}) → PrinterContentBuilder -
addQRCode(
String data, {PrinterTextAlignment alignment = PrinterTextAlignment.center, int size = 100, int errorCorrection = 2}) → PrinterContentBuilder -
append(
String text) → PrinterContentBuilder -
appendLine(
[String text = '']) → PrinterContentBuilder -
bold(
) → PrinterContentBuilder -
build(
) → String -
center(
) → PrinterContentBuilder -
content(
String text) → PrinterContentBuilder -
left(
) → PrinterContentBuilder -
line(
[String char = '=', int length = 32]) → PrinterContentBuilder -
lineSpacing(
double spacing) → PrinterContentBuilder -
newLine(
[int count = 1]) → PrinterContentBuilder -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reset(
) → void -
right(
) → PrinterContentBuilder -
row(
List< String> columns, {List<int> ? widths}) → PrinterContentBuilder -
size(
int size) → PrinterContentBuilder -
toString(
) → String -
A string representation of this object.
inherited
-
underline(
) → PrinterContentBuilder
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited