LoggerService<T> class abstract

Implementers

Constructors

LoggerService()

Properties

hashCode int
The hash code for this object.
no setterinherited
kInstance ↔ T?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings LoggerSettings?
no setter

Methods

debug(dynamic caller, String message, {dynamic error, StackTrace? stackTrace, Map<String, dynamic>? extra}) → void
Logs a debug message.
error(dynamic caller, String message, {dynamic error, StackTrace? stackTrace, Map<String, dynamic>? extra}) → void
Logs an error message.
info(dynamic caller, String message, {dynamic error, StackTrace? stackTrace, Map<String, dynamic>? extra}) → void
Logs an info message.
initialize({required LoggerSettings settings}) Future<void>
log(dynamic caller, {required LogLevel level, required String message, dynamic error, StackTrace? stackTrace, Map<String, dynamic>? extra}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onInitialise(LoggerSettings settings) → void
toString() String
A string representation of this object.
inherited
verbose(dynamic caller, String message, {dynamic error, StackTrace? stackTrace, Map<String, dynamic>? extra}) → void
Logs a verbose message.
warning(dynamic caller, String message, {dynamic error, StackTrace? stackTrace, Map<String, dynamic>? extra}) → void
Logs a warning message.
wtf(dynamic caller, String message, {dynamic error, StackTrace? stackTrace, Map<String, dynamic>? extra}) → void
Logs a severe error message (What a Terrible Failure).

Operators

operator ==(Object other) bool
The equality operator.
inherited