observability/observability_service library
Classes
Typedefs
- ObservabilityWidgetWrapper = Widget Function(Widget child)
- A function that wraps a child widget with an observability wrapper. Used by providers like Sentry that require wrapping the root widget for features like screenshot capture.