ObservabilityWidgetWrapper typedef
A function that wraps a child widget with an observability wrapper. Used by providers like Sentry that require wrapping the root widget for features like screenshot capture.
Implementation
typedef ObservabilityWidgetWrapper = Widget Function(Widget child);