ThemeSettings class
Constructors
- ThemeSettings({AppStyle appStyle = const AppStyle(), ButtonStyles buttonStyles = const ButtonStyles(), CardStyle cardStyle = const CardStyle(), AppBarStyle appBarStyle = const AppBarStyle(), ColorPalette colorPalette = const ColorPalette(), FormStyle formStyles = const FormStyle(), TypographySettings typographySettings = const TypographySettings(), LocalisationSettings localizationSettings = const LocalisationSettings()})
-
const
-
ThemeSettings.fromJson(Map<
String, dynamic> ? json) -
factory
Properties
- appBarStyle → AppBarStyle
-
final
- appStyle → AppStyle
-
final
-
final
- cardStyle → CardStyle
-
final
- colorPalette → ColorPalette
-
final
- formStyles → FormStyle
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- localizationSettings → LocalisationSettings
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typographySettings → TypographySettings
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited