AppBarStyle class
Constructors
- AppBarStyle({bool appBarUseGradient = false, ColorItem appBarGradientStart = const ColorItem(), ColorItem appBarGradientEnd = const ColorItem(), ColorItem appBarBackground = const ColorItem(), bool appBarEnableSurfaceTint = false, bool useStatusBarDark = false, int appBarStartAlpha = 255, int appBarEndAlpha = 255, double appBarElevation = 0.0, ColorItem appBarForeground = const ColorItem()})
-
const
-
AppBarStyle.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appBarBackground → ColorItem
-
final
- appBarElevation → double
-
final
- appBarEnableSurfaceTint → bool
-
final
- appBarEndAlpha → int
-
final
- appBarForeground → ColorItem
-
final
- appBarGradientEnd → ColorItem
-
final
- appBarGradientStart → ColorItem
-
final
- appBarStartAlpha → int
-
final
- appBarUseGradient → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useStatusBarDark → bool
-
final
Methods
-
copyWith(
{bool? appBarUseGradient, ColorItem? appBarGradientStart, ColorItem? appBarGradientEnd, ColorItem? appBarBackground, bool? appBarEnableSurfaceTint, bool? useStatusBarDark, int? appBarStartAlpha, int? appBarEndAlpha, double? appBarElevation, ColorItem? appBarForeground}) → AppBarStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited