LocalisationSettings class
Constructors
- LocalisationSettings({String isoLanguageCode = 'za', String isoCurrencyCode = 'ZAR', String isoCountryCode = 'RSA', String isoTimezone = '+02:00', String dateFormat = 'dd-MM-yyyy', String timeFormat = 'HH:mm'})
-
const
-
LocalisationSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- dateFormat → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isoCountryCode → String
-
final
- isoCurrencyCode → String
-
final
- isoLanguageCode → String
-
final
- isoTimezone → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeFormat → String
-
final
Methods
-
copyWith(
{String? isoLanguageCode, String? isoCurrencyCode, String? isoCountryCode, String? isoTimezone, String? dateFormat, String? timeFormat}) → LocalisationSettings -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited